import { ElementRef, Renderer2, OnDestroy } from '@angular/core';
/**
 * Possible value for hover/focus highlight style.
 *
 * shadow:
 * adds a thin shadow around the element.
 *
 * outline:
 * adds a thibk, more pronounced shadow around the element. A shadow is used
 * instead of a border to avoid the element jumping around.
 *
 * background:
 * change the element's background color.
 *
 * none:
 * No highlight effect is applied.
 */
export declare type HighlightStyle = 'shadow' | 'outline' | 'background' | 'none';
/**
 * Specifies the highlight styles for hover and/or focus.
 */
export declare type HighlightStyleConfig = {
    hover?: HighlightStyle;
    focus?: HighlightStyle;
};
/**
 * Default highlight styles: `none` for hover and `none` for focus.
 */
export declare const DEFAULT_STYLE_CONFIG: Readonly<HighlightStyleConfig>;
/**
 * Default debounce time for mouse/focus events.
 */
export declare const DEFAULT_DEBOUNCE_TIME = 50;
export declare class HighlightDirective implements OnDestroy {
    private _renderer;
    private _el;
    /**
     * The currently set highlight styles for the directive.
     */
    get highlightStyle(): HighlightStyleConfig;
    set highlightStyle(value: HighlightStyleConfig);
    /**
     * The currently set debounce time for the directive.
     *
     * Events are debounced to limit the frequency at which hover and/or focus
     * styles are applied/removed and provide a nicer user experience. A value of
     * `0` completely disables debouncing.
     */
    get hcHighlightDebounce(): number;
    set hcHighlightDebounce(value: number);
    private _style;
    private _debounceTime;
    private _hovered$;
    private _isHovered;
    private _focused$;
    private _isFocused;
    private _subscriptions;
    constructor(_renderer: Renderer2, _el: ElementRef);
    ngOnDestroy(): void;
    onMouseEnter(): void;
    onMouseLeave(): void;
    onFocusIn(): void;
    onFocusOut(): void;
    private _updateStyleConfig;
    private _updateDebounceTime;
    private _startHoverSubscription;
    private _stopHoverSubscription;
    private _startFocusSubscription;
    private _stopFocusSubscription;
    private _applyEffect;
    private _removeEffect;
}
